Internal function to format cv_set for analysis
get_cv_subsets.RdInternal function to format cv_set for analysis
Arguments
- cv_set
list of analysis and assessment data.frames
- y_var
name of variable to predict
- pred_vars
predictor variables used in model, or grouping variables in the case of
fit_naive(). Default = NULL- remove_NA
whether to remove missing y observations from analysis data. Default = FALSE